.. _astro:

**************************************************************
Astrophysical source and population models (``gammapy.astro``)
**************************************************************

.. currentmodule:: gammapy.astro

Introduction
============

Common astrophysical source and population models are implemented in
`gammapy.astro.source` and `gammapy.astro.population`.

The ``gammapy.astro`` namespace is empty ... use these import statements::

   from gammapy.astro import source
   from gammapy.astro import population

.. toctree::
  :maxdepth: 1

  source/index
  population/index

Getting Started
===============



Example
=======

TODO: Galactic gamma-ray source population model (catalog distributions, flux image, significance images)
